#include "crogue.h"

static void Graph_DrawTile_Monochrome(UI_Tilefield *tf, int x, int y, UI_TF_TileInfo tile) SEG(1);

//{{{
void Graph_DrawTile(UI_Tilefield *tf, int x, int y, UI_TF_TileInfo tile)
{
	int tile_map;
	RectangleType r;
	
	if(monochrome_screen) {
		Graph_DrawTile_Monochrome(tf, x, y, tile);
		return;
	}
	
	WinPushDrawState();
	r.topLeft.x = tf->pos.x + x*tf->tilewidth;
	r.topLeft.y = tf->pos.y + y*tf->tileheight;
	r.extent.x = tf->tilewidth;
	r.extent.y = tf->tileheight;
	
	FntSetFont(TileFont);
	WinSetTextColor(COLOR_BLACK);
	tile_map = tile.tile;
	if(tile_map < 32) // Ctl char range. In Palm font, this is mapped to 128+N
		tile_map += 128;
	
	switch(tile.lighting)
	{
		case LIGHTING_LIT:
			WinSetBackColor(COLOR_WHITE);
			Graph_DrawChar(tf->pos.x + x*tf->tilewidth,
						   tf->pos.y + y*tf->tileheight,
						   tile_map);
			break;
		case LIGHTING_DARK:
			WinSetBackColor(COLOR_LIGHT_GRAY);
			Graph_DrawChar(tf->pos.x + x*tf->tilewidth,
						   tf->pos.y + y*tf->tileheight,
						   tile_map);
			break;
		case LIGHTING_UNEXPLORED:
			WinSetForeColor(COLOR_DARK_GRAY);
			WinDrawRectangle(&r, 0);
			break;
	}
	FntSetFont(TextFont);
	WinPopDrawState();
}
//}}}
//{{{
static void Graph_DrawTile_Monochrome(UI_Tilefield *tf, int x, int y, UI_TF_TileInfo tile)
{
	int tile_map;
	RectangleType r;
	
	r.topLeft.x = tf->pos.x + x*tf->tilewidth;
	r.topLeft.y = tf->pos.y + y*tf->tileheight;
	r.extent.x = tf->tilewidth;
	r.extent.y = tf->tileheight;
	
	FntSetFont(TileFont);
	
	switch(tile.lighting)
	{
		case LIGHTING_LIT:
			if(tile.tile == 3) tile.tile = 4;
		case LIGHTING_DARK:
			tile_map = tile.tile;
			if(tile_map < 32) // Ctl char range, mapped to 128+N
				tile_map += 128;
			
			Graph_DrawChar(tf->pos.x + x*tf->tilewidth,
						   tf->pos.y + y*tf->tileheight,
						   tile_map);
			break;
		case LIGHTING_UNEXPLORED:
			Graph_DrawChar(tf->pos.x + x*tf->tilewidth,
						   tf->pos.y + y*tf->tileheight,
						   128+17);
			break;
	}
	FntSetFont(TextFont);
}
//}}}

//{{{
void Graph_ClrScr(void)
{
	WinEraseWindow();
}
//}}}
//{{{
void Graph_ClearRect(int left, int top, int right, int bottom)
{
	RectangleType r;
	r.topLeft.x = left;
	r.topLeft.y = top;
	r.extent.x = right-left+1;
	r.extent.y = bottom-top+1;
	WinEraseRectangle(&r, 0);
}
//}}}
//{{{
void Graph_DrawRect(int left, int top, int right, int bottom)
{
	Graph_DrawLine(left, top, right, top);
	Graph_DrawLine(right, top, right, bottom);
	Graph_DrawLine(right, bottom, left, bottom);
	Graph_DrawLine(left, bottom, left, top);
}
//}}}
//{{{
void Graph_DrawLine(short x0, short y0, short x1, short y1)
{
	WinDrawLine(x0, y0, x1, y1);
	WinDrawLine(x0, y0, x1, y1);
}
//}}}
//{{{
void Graph_DrawChar(short x, short y, char c)
{
	WinGlueDrawChar((unsigned char)c, x, y);
}
//}}}
//{{{
void Graph_DrawStr(short x, short y, const char *str)
{
	WinDrawChars(str, strlen(str), x, y);
}
//}}}
//{{{
void Graph_ScrRectXor(int left, int top, int width, int height)
{
	RectangleType r;
	r.topLeft.x = left;
	r.topLeft.y = top;
	r.extent.x = width;
	r.extent.y = height;
	WinInvertRectangle(&r, 0);
}
//}}}

